_`umbra.components.factory.componentsManagerUi.views`
=====================================================

.. automodule:: umbra.components.factory.componentsManagerUi.views

Module Attributes
-----------------

.. attribute:: umbra.components.factory.componentsManagerUi.views.LOGGER

Classes
-------

.. autoclass:: Components_QTreeView
	:show-inheritance:
	:members:

